Take data on uniform margins and fit the Ledford and Tawn (1997) joint tail model. Also contains the method where additional information from values that are extreme in at most one variable is used.
Bv.LT.Dep(
data,
mod.thresh.u,
crit.lev.u,
sig.lev = 0.05,
ci.meth = "se",
marg.inf = F
)Two column data frame with values given on uniform margins
Modelling threshold on uniform margin
Critical level on uniform margin
Significance level for confidence intervals (default 0.05 for 95% confidence interval)
Method to use to obtain confidence intervals, 'se' for standard error confidence intervals and 'pl' for profile likelihood confidence intervals
Is additional marginal information from points that are extreme in only one variable used? FALSE gives Ledford and Tawn (1997) result, TRUE gives results using Section 2.4.2 from Hugo Winter's thesis.
Estimates of two dependence parameters with confidence intervals:
threshold dependent extremal dependence measure
threshold dependent coefficient of tail dependence